<?php
/*
Plugin Name: Read More: Patchset
Plugin URI: http://www.bashelton.com
Description: Provides access to changing your "read more" teaser text from the
plugin control panel as well as options for wrapping the link in other HTML.
Version: 0.1
Author: Benjamin A. Shelton
Author URI: http://www.bashelton.com
*/

function read_more_patchset_filter ($content) {
        global $id, $post, $more, $page, $pages, $multipage, $preview, $pagenow, $read_more_vars;
        
        $stripteaser = false;
        $more_file = '';
        /*$before = '<div class="post_read_more">';
        $after  = '</div>';        
        $more_link_text = 'I want to read more...';*/
        $more_link_text = get_option('rmp_more_link_text');
        $before         = get_option('rmp_before_text');
        $after          = get_option('rmp_after_text');
        
        if ( null === $more_link_text )
                $more_link_text = __( '(more...)' );

        $output = '';
        
        // If post password required and it doesn't match the cookie.
        if ( post_password_required($post) ) {
                $output = get_the_password_form();
                return $output;
        }

        if ( $more_file != '' )
                $file = $more_file;
        else
                $file = $pagenow; //$_SERVER['PHP_SELF'];

        if ( $page > count($pages) ) // if the requested page doesn't exist
                $page = count($pages); // give them the highest numbered page that DOES exist

        $content = $pages[$page-1];
        if ( preg_match('/<!--more(.*?)?-->/', $content, $matches) ) {
                $content = explode($matches[0], $content, 2);
                if ( !empty($matches[1]) && !empty($more_link_text) )
                        $more_link_text = strip_tags(wp_kses_no_null(trim($matches[1])));
        } else {
                $content = array($content);
        }
        if ( (false !== strpos($post->post_content, '<!--noteaser-->') && ((!$multipage) || ($page==1))) )
                $stripteaser = 1;
        $teaser = $content[0];
        if ( ($more) && ($stripteaser) )
                $teaser = '';
        $output .= $teaser;
        if ( count($content) > 1 ) {
                if ( $more ) {
                        $output .= '<span id="more-'.$id.'"></span>'.$content[1];
                } else {
                    if ( ! empty ($before) )
                        $output .= $before;
                        $output = balanceTags($output);
                        if ( ! empty($more_link_text) )
                                $output .= ' <a href="'. get_permalink() . "#more-$id\" class=\"more-link\">$more_link_text</a>";
                    if ( ! empty ($after) )
                        $output .= $after;
                }

        }
        if ( $preview ) // preview fix for javascript bug with foreign languages
                $output =       preg_replace_callback('/\%u([0-9A-F]{4})/', create_function('$match', 'return "&#" . base_convert($match[1], 16, 10) . ";";'), $output);

        return $output;
} // end read_more_patchset_filter ()

function read_more_admin_menu ()
{
	add_options_page('RM Patchset Options', 'Read More Patchset', 8, __FILE__, 'read_more_options_page');            
} 

function read_more_options_page ()
{
    if (isset($_POST['submitted'])) {
        check_admin_referer('read-more-patchset');
        $more_link_text = stripslashes($_POST['rmp_more_link_text']);
        $before         = stripslashes($_POST['rmp_before_text']);
        $after          = stripslashes($_POST['rmp_after_text']);
        
        update_option('rmp_more_link_text', $more_link_text);
        update_option('rmp_before_text', $before);
        update_option('rmp_after_text', $after);
        
        $msg = 'Read More Patchset settings saved.';
        _e('<div id="message" class="updated fade"><p>'.$msg.'</p></div>');
    }
    
    $more_link_text = htmlentities(get_option('rmp_more_link_text'));
    $before         = htmlentities(get_option('rmp_before_text'));
    $after          = htmlentities(get_option('rmp_after_text'));
 
    $actionurl=$_SERVER['REQUEST_URI'];
    $nonce=wp_create_nonce('read-more-patchset');
 
    echo <<<END
<div class="wrap">
<h2>Read More Patchset</h2>
<p>This plugin provides additional configuration options to change the "read
more" link displayed wherever you've set a teaser using the &lt!--more--&gt;
tag.</p>

<div class="dbx-content">
<form name="rmpform" action="$action_url" method="post">
<input type="hidden" name="submitted" value="1" /> 
<input type="hidden" id="_wpnonce" name="_wpnonce" value="$nonce" />
<h3>Change Settings</h3>
<p>"Read More" link text (defaults to "Read more..."):<br />
<input type="text" name="rmp_more_link_text" value="$more_link_text" /><br />
Text or HTML to display <i>before</i> the link text:<br />
<input type="text" name="rmp_before_text" value="$before" /><br />
Text or HTML to display <i>after</i> the link text:<br />
<input type="text" name="rmp_after_text" value="$after" /><br />
<div class="submit"><input type="submit" name="Submit" value="Apply Changes" /></div>
</div>    
</form></div>
END;

}

function read_more_patchset_install ()
{
    if (!get_option('rmp_more_link_text') || get_option('rmp_more_link_text') == '')
        add_option('rmp_more_link_text', 'Read more...');
    if (get_option('rmp_before_text') === false)
        add_option('rmp_before_text', '');
    if (get_option('rmp_after_text') === false)
        add_option('rmp_after_text', '');
}

if (isset($_GET['activate']) && $_GET['activate'] == 'true') {
    read_more_patchset_install();
}

add_filter ('the_content', 'read_more_patchset_filter', 0);
add_action ('admin_menu', 'read_more_admin_menu');

?>